1.14.8 — Rucio 1.2 documentation

# 1.14.8

## General

### Enhancements

- Probes & Alarms: Move the methods calls in check_rse_attributes from the API to the core #519
- RSE Manager: Remove <operation>_protocol entries in rse_settings #508
- RSE Manager: rsemanager add domain to all method signatures #62
- Rules: Possibility to give reason when denying a rule #487
- Transfers: Conveyor should only use schemes compatible to the destination scheme #73

### Bugs

- Core & Internals: set_metadata should update guid both in did and content table #413
- Core & Internals: Creating incomplete message for datasets does not work #464
- Core & Internals: Postgres error in conveyor-finisher #480
- Probes & Alarms: Probe setting the naming convention is broken #522
- Recovery: Crash when declaring bad file replicas already declared bad on a non-deterministic RSE #457
- Traces: heartbeats do not work correctly for kronos dataset thread #510
- Transfers: Conveyor receiver does not consume messages #513

## Clients

### Enhancements

- Clients: update-rule –lifetime command does not work #496

### Bugs

- Clients: Force GSI authentication for root fix did not work #467
- Clients: Automatic protocol failover broken in rucio download #502

## WebUI

### Features

- WebUI: WebUI: Preview logfiles in browser #344 #344
- WebUI: Rucio UI Account admin view #81

### Enhancements

- WebUI: Admin interface in Rucio UI #78